@@ -73,6 +73,8 @@ pub struct ArgMatches {
     pub(crate) valid_args: Vec<Id>,
     #[cfg(debug_assertions)]
     pub(crate) valid_subcommands: Vec<Id>,
+    #[cfg(debug_assertions)]
+    pub(crate) disable_asserts: bool,
     pub(crate) args: IndexMap<Id, MatchedArg>,
     pub(crate) subcommand: Option<Box<SubCommand>>,
 }
@@ -1005,7 +1007,7 @@ impl ArgMatches {
         #[cfg(debug_assertions)]
         {
             let id = Id::from(_id);
-            id == Id::empty_hash() || self.valid_args.contains(&id)
+            self.disable_asserts || id == Id::empty_hash() || self.valid_args.contains(&id)
         }
         #[cfg(not(debug_assertions))]
         {
@@ -1024,7 +1026,7 @@ impl ArgMatches {
         #[cfg(debug_assertions)]
         {
             let id = Id::from(_id);
-            id == Id::empty_hash() || self.valid_subcommands.contains(&id)
+            self.disable_asserts || id == Id::empty_hash() || self.valid_subcommands.contains(&id)
         }
         #[cfg(not(debug_assertions))]
         {
@@ -1040,15 +1042,15 @@ impl ArgMatches {
     fn get_arg(&self, arg: &Id) -> Option<&MatchedArg> {
         #[cfg(debug_assertions)]
         {
-            if *arg == Id::empty_hash() || self.valid_args.contains(arg) {
+            if self.disable_asserts || *arg == Id::empty_hash() || self.valid_args.contains(arg) {
             } else if self.valid_subcommands.contains(arg) {
                 panic!(
-                    "Subcommand `'{:?}' used where an argument or group name was expected.",
+                    "Subcommand `{:?}` used where an argument or group name was expected.",
                     arg
                 );
             } else {
                 panic!(
-                    "`'{:?}' is not a name of an argument or a group.\n\
+                    "`{:?}` is not a name of an argument or a group.\n\
                      Make sure you're using the name of the argument itself \
                      and not the name of short or long flags.",
                     arg
@@ -1064,14 +1066,17 @@ impl ArgMatches {
     fn get_subcommand(&self, id: &Id) -> Option<&SubCommand> {
         #[cfg(debug_assertions)]
         {
-            if *id == Id::empty_hash() || self.valid_subcommands.contains(id) {
+            if self.disable_asserts
+                || *id == Id::empty_hash()
+                || self.valid_subcommands.contains(id)
+            {
             } else if self.valid_args.contains(id) {
                 panic!(
-                    "Argument or group `'{:?}' used where a subcommand name was expected.",
+                    "Argument or group `{:?}` used where a subcommand name was expected.",
                     id
                 );
             } else {
-                panic!("'{:?}' is not a name of a subcommand.", id);
+                panic!("`{:?}` is not a name of a subcommand.", id);
             }
         }
 
